@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-# $Id: controlpanel.py 113853 2010-03-23 15:43:02Z glenfant $
+# $Id: controlpanel.py 146677 2010-10-21 15:24:51Z glenfant $
 """ZMI control panel"""
 
 import Acquisition
-import Globals
 from OFS import SimpleItem
 from App.version_txt import getZopeVersion
 version = getZopeVersion()
@@ -12,8 +11,11 @@ if version > (2, 12):
         pass
 else:
     from App.ApplicationManager import Fake
+
 from Products.PageTemplates.PageTemplateFile import PageTemplateFile
 
+from config import CONTROLPANEL_ID
+
 all_patches = []
 
 def monkeyPatchAdded(event):
@@ -25,10 +27,8 @@ def monkeyPatchAdded(event):
 class ControlPanel(Fake, SimpleItem.Item, Acquisition.Implicit):
     """The Monkey patches control panel"""
 
-    id = 'collective_monkeypatcherpanel'
+    id = CONTROLPANEL_ID
     name = title = "Monkey Patches"
-    meta_type = "Monkey patches control panel"
-    icon = 'misc_/collective.monkeypatcherpanel/icon.png'
     manage_main = PageTemplateFile('zmi/controlpanel.pt', globals())
 
     manage_options=((
@@ -41,4 +41,3 @@ class ControlPanel(Fake, SimpleItem.Item, Acquisition.Implicit):
     def allPatches(self):
         return all_patches
 
-Globals.InitializeClass(ControlPanel)
